package com.ruoyi.common.utils;

import java.lang.management.ManagementFactory;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.*;
import java.time.format.DateTimeFormatter;
import java.time.format.DateTimeFormatterBuilder;
import java.time.temporal.ChronoField;
import java.time.temporal.TemporalAdjusters;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

import org.apache.commons.lang3.time.DateFormatUtils;

/**
 * 时间工具类
 *
 * @author ruoyi
 */
public class DateUtils extends org.apache.commons.lang3.time.DateUtils {
    public static String YYYY = "yyyy";

    public static String YYYY_MM = "yyyy-MM";

    public static String YYYY_MM_DD = "yyyy-MM-dd";

    public static String YYYYMMDD = "yyyyMMdd";

    public static String YYYYMMDDHHMMSS = "yyyyMMddHHmmss";

    public static String YYYY_MM_DD_HH_MM_SS = "yyyy-MM-dd HH:mm:ss";

    private static String[] parsePatterns = {
            "yyyy-MM-dd", "yyyy-MM-dd HH:mm:ss", "yyyy-MM-dd HH:mm", "yyyy-MM",
            "yyyy/MM/dd", "yyyy/MM/dd HH:mm:ss", "yyyy/MM/dd HH:mm", "yyyy/MM",
            "yyyy.MM.dd", "yyyy.MM.dd HH:mm:ss", "yyyy.MM.dd HH:mm", "yyyy.MM"};

    /**
     * 获取当前Date型日期
     *
     * @return Date() 当前日期
     */
    public static Date getNowDate() {
        return new Date();
    }

    /**
     * 获取当前日期, 默认格式为yyyy-MM-dd
     *
     * @return String
     */
    public static String getDate() {
        return dateTimeNow(YYYY_MM_DD);
    }

    public static final String getTime() {
        return dateTimeNow(YYYY_MM_DD_HH_MM_SS);
    }

    public static final String dateTimeNow() {
        return dateTimeNow(YYYYMMDDHHMMSS);
    }

    public static final String dateTimeNow(final String format) {
        return parseDateToStr(format, new Date());
    }

    public static final String dateTime(final Date date) {
        return parseDateToStr(YYYY_MM_DD, date);
    }

    public static final String parseDateToStr(final String format, final Date date) {
        return new SimpleDateFormat(format).format(date);
    }

    public static final Date dateTime(final String format, final String ts) {
        try {
            return new SimpleDateFormat(format).parse(ts);
        } catch (ParseException e) {
            throw new RuntimeException(e);
        }
    }

    /**
     * 日期路径 即年/月/日 如2018/08/08
     */
    public static final String datePath() {
        Date now = new Date();
        return DateFormatUtils.format(now, "yyyy/MM/dd");
    }

    /**
     * 日期路径 即年/月/日 如20180808
     */
    public static final String dateTime() {
        Date now = new Date();
        return DateFormatUtils.format(now, "yyyyMMdd");
    }

    /**
     * 日期型字符串转化为日期 格式
     */
    public static Date parseDate(Object str) {
        if (str == null) {
            return null;
        }
        try {
            return parseDate(str.toString(), parsePatterns);
        } catch (ParseException e) {
            return null;
        }
    }

    /**
     * 获取服务器启动时间
     */
    public static Date getServerStartDate() {
        long time = ManagementFactory.getRuntimeMXBean().getStartTime();
        return new Date(time);
    }

    /**
     * 计算相差天数
     */
    public static int differentDaysByMillisecond(Date date1, Date date2) {
        return Math.abs((int) ((date2.getTime() - date1.getTime()) / (1000 * 3600 * 24)));
    }

    /**
     * 计算时间差
     *
     * @param endDate   最后时间
     * @param startTime 开始时间
     * @return 时间差（天/小时/分钟）
     */
    public static String timeDistance(Date endDate, Date startTime) {
        long nd = 1000 * 24 * 60 * 60;
        long nh = 1000 * 60 * 60;
        long nm = 1000 * 60;
        // long ns = 1000;
        // 获得两个时间的毫秒时间差异
        long diff = endDate.getTime() - startTime.getTime();
        // 计算差多少天
        long day = diff / nd;
        // 计算差多少小时
        long hour = diff % nd / nh;
        // 计算差多少分钟
        long min = diff % nd % nh / nm;
        // 计算差多少秒//输出结果
        // long sec = diff % nd % nh % nm / ns;
        return day + "天" + hour + "小时" + min + "分钟";
    }

    /**
     * 增加 LocalDateTime ==> Date
     */
    public static Date toDate(LocalDateTime temporalAccessor) {
        ZonedDateTime zdt = temporalAccessor.atZone(ZoneId.systemDefault());
        return Date.from(zdt.toInstant());
    }

    /**
     * 增加 LocalDate ==> Date
     */
    public static Date toDate(LocalDate temporalAccessor) {
        LocalDateTime localDateTime = LocalDateTime.of(temporalAccessor, LocalTime.of(0, 0, 0));
        ZonedDateTime zdt = localDateTime.atZone(ZoneId.systemDefault());
        return Date.from(zdt.toInstant());
    }

    /**
     * 获取指定日期的下周一
     *
     * @param date
     * @param format
     * @return
     */
    public static String getNextMonday(String date, String format) {
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern(format);
        LocalDate localDate = LocalDate.parse(date, formatter);
        DayOfWeek dayWeek = localDate.getDayOfWeek();
        int number = DayOfWeek.MONDAY.getValue() - dayWeek.getValue();
        number = number <= 0 ? 7 + number : number;
        LocalDate nextDay = localDate.plusDays(number);
        return nextDay.format(formatter);
    }

    /**
     * 获取指定日期的下周日
     *
     * @param date
     * @param format
     * @return
     */
    public static String getNextSunday(String date, String format) {
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern(format);
        LocalDate localDate = LocalDate.parse(date, formatter);
        DayOfWeek dayWeek = localDate.getDayOfWeek();
        int number = DayOfWeek.SUNDAY.getValue() - dayWeek.getValue();
        number = number <= 0 ? 7 + number : number;
        LocalDate nextDay = localDate.plusDays(number);
        return nextDay.format(formatter);
    }

    /**
     * 获取指定日期前后N天的日期
     *
     * @param dateStr 日期字符串
     * @param format  格式
     * @param number  天数
     * @return
     */
    public static String getNextDateStr(String dateStr, String format, int number) {
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern(format);
        LocalDate localDate = LocalDate.parse(dateStr, formatter);
        // 获取后N天的日期
        LocalDate nextDay = localDate.plusDays(number);
        return nextDay.format(formatter);
    }

    /**
     * 获取上个月的第一天
     *
     * @param format
     * @return
     */
    public static String getFirstDateLastMonthStr(String format) {
        LocalDate now = LocalDate.now();
        LocalDate firstDayOfLastMonth = now.with(TemporalAdjusters.firstDayOfMonth()).minusMonths(1);
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern(format);
        return firstDayOfLastMonth.format(formatter);
    }

    /**
     * 获取上个月的最后一天
     *
     * @param format
     * @return
     */
    public static String getLastDateLastMonthStr(String format) {
        LocalDate now = LocalDate.now();
        LocalDate previousMonth = now.minusMonths(1);
        int lastDayOfPreviousMonth = previousMonth.lengthOfMonth();
        LocalDate lastDateOfPreviousMonth = LocalDate.of(previousMonth.getYear(), previousMonth.getMonth(), lastDayOfPreviousMonth);
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern(format);
        return lastDateOfPreviousMonth.format(formatter);
    }

    public static String covertStrToLocalTime(String dateTimeStr) {
        SimpleDateFormat sdf = new SimpleDateFormat("EEE MMM dd yyyy HH:mm:ss 'GMT'Z' (中国标准时间)'", Locale.ENGLISH);
        SimpleDateFormat sdf2 = new SimpleDateFormat(YYYY_MM_DD_HH_MM_SS);
        try {
            Date date=sdf.parse(dateTimeStr);
            return sdf2.format(date);
            //Date newStartDate =sdf2.parse(stDate);
           //return new java.sql.Date(newStartDate.getTime());
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return null;
    }

    /**
     * 获取上周一
     * @param format
     * @return
     */
    public static String getLastMonday(String format){
        Calendar calendar = Calendar.getInstance();
        calendar.add(Calendar.DATE, -7);  // 获取上一周
        calendar.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY);  // 设置为周一
        Date monday = calendar.getTime();
        SimpleDateFormat sdf = new SimpleDateFormat(format);
        return sdf.format(monday);
    }

    /**
     * 获取上周日
     * @param format
     * @return
     */
    public static String getLastSunday(String format){
        Calendar calendar = Calendar.getInstance();
        calendar.add(Calendar.DATE, -7);  // 获取上一周
        calendar.set(Calendar.DAY_OF_WEEK, Calendar.MONDAY);
        calendar.add(Calendar.DATE, 6);
        Date sunday = calendar.getTime();
        SimpleDateFormat sdf = new SimpleDateFormat(format);
        return sdf.format(sunday);
    }


    public static void main(String[] args)throws Exception {
        //System.out.println(getNextMonday("20241125",YYYYMMDD));
       // System.out.println(covertStrToLocalTime("Fri Jan 17 2025 00:00:00 GMT+0800 (中国标准时间)"));

        System.out.println(getLastMonday(YYYY_MM_DD));
        System.out.println(getLastSunday(YYYY_MM_DD));
    }

}
