package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.bean.BeanListUtils;
import com.ruoyi.powerdistribution.domain.vo.PdmScoreRankTeamOut;
import com.ruoyi.powerdistribution.domain.vo.PdmScoreRankTeamYear;
import com.ruoyi.powerdistribution.domain.vo.PdmScoreRankTeamYearOut;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmScoreRankTeam;
import com.ruoyi.powerdistribution.service.IPdmScoreRankTeamService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 队伍积分排名Controller
 *
 * @author ruoyi
 * @date 2024-12-05
 */
@RestController
@RequestMapping("/power/teamRank")
public class PdmScoreRankTeamController extends BaseController
{
    @Autowired
    private IPdmScoreRankTeamService pdmScoreRankTeamService;

    /**
     * 查询队伍积分排名列表
     */
    @ApiOperation(value = "查询队伍积分排名列表")
    @GetMapping("/list")
    public TableDataInfo list(PdmScoreRankTeam pdmScoreRankTeam)
    {
        startPage();
        List<PdmScoreRankTeam> list = pdmScoreRankTeamService.selectScoreRankTeamList(pdmScoreRankTeam);
        return getDataTable(list);
    }

    /**
     * 导出队伍积分排名列表
     */
    @ApiOperation(value = "导出队伍积分排名列表")
    @Log(title = "队伍积分排名", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmScoreRankTeam pdmScoreRankTeam)
    {
        List<PdmScoreRankTeam> list = pdmScoreRankTeamService.selectScoreRankTeamList(pdmScoreRankTeam);
        if ("2".equals(pdmScoreRankTeam.getTeamType()) && StringUtils.isNotEmpty(pdmScoreRankTeam.getReportYear())) {
            //外部-年
            List<PdmScoreRankTeamYearOut> newList = BeanListUtils.copyListProperties(list,PdmScoreRankTeamYearOut::new);
            ExcelUtil<PdmScoreRankTeamYearOut> util = new ExcelUtil<>(PdmScoreRankTeamYearOut.class);
            util.exportExcel(response, newList, "队伍积分排名数据");
        }else if ("2".equals(pdmScoreRankTeam.getTeamType()) && StringUtils.isEmpty(pdmScoreRankTeam.getReportYear())) {
            //外部-月
            List<PdmScoreRankTeamOut> newList = BeanListUtils.copyListProperties(list,PdmScoreRankTeamOut::new);
            ExcelUtil<PdmScoreRankTeamOut> util = new ExcelUtil<>(PdmScoreRankTeamOut.class);
            util.exportExcel(response, newList, "队伍积分排名数据");
        }else if("1".equals(pdmScoreRankTeam.getTeamType()) && StringUtils.isNotEmpty(pdmScoreRankTeam.getReportYear())){
            //内部-年
            List<PdmScoreRankTeamYear> newList = BeanListUtils.copyListProperties(list,PdmScoreRankTeamYear::new);
            ExcelUtil<PdmScoreRankTeamYear> util = new ExcelUtil<>(PdmScoreRankTeamYear.class);
            util.exportExcel(response, newList, "队伍积分排名数据");
       } else{
            //内部-月
            ExcelUtil<PdmScoreRankTeam> util = new ExcelUtil<>(PdmScoreRankTeam.class);
            util.exportExcel(response, list, "队伍积分排名数据");
        }
    }

    /**
     * 获取队伍积分排名详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmScoreRankTeamService.selectPdmScoreRankTeamById(id));
    }

    /**
     * 新增队伍积分排名
     */
    @Log(title = "队伍积分排名", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmScoreRankTeam pdmScoreRankTeam)
    {
        return toAjax(pdmScoreRankTeamService.insertPdmScoreRankTeam(pdmScoreRankTeam));
    }

    /**
     * 修改队伍积分排名
     */
    @Log(title = "队伍积分排名", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmScoreRankTeam pdmScoreRankTeam)
    {
        return toAjax(pdmScoreRankTeamService.updatePdmScoreRankTeam(pdmScoreRankTeam));
    }

    /**
     * 删除队伍积分排名
     */
    @Log(title = "队伍积分排名", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmScoreRankTeamService.deletePdmScoreRankTeamByIds(ids));
    }
}
