package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.bean.BeanListUtils;
import com.ruoyi.powerdistribution.domain.vo.*;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmScoreRankWorker;
import com.ruoyi.powerdistribution.service.IPdmScoreRankWorkerService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 作业人员积分排名Controller
 *
 * @author ruoyi
 * @date 2024-12-05
 */
@RestController
@RequestMapping("/power/workerRank")
public class PdmScoreRankWorkerController extends BaseController
{
    @Autowired
    private IPdmScoreRankWorkerService pdmScoreRankWorkerService;

    /**
     * 查询作业人员积分排名列表
     */
    @ApiOperation(value = "查询作业人员积分排名列表")
    @GetMapping("/list")
    public TableDataInfo list(PdmScoreRankWorker pdmScoreRankWorker)
    {
        startPage();
        List<PdmScoreRankWorker> list = pdmScoreRankWorkerService.selectScoreRankWorkerList(pdmScoreRankWorker);
        return getDataTable(list);
    }

    /**
     * 导出作业人员积分排名列表
     */
    @ApiOperation(value = "导出作业人员积分排名列表")
    @Log(title = "作业人员积分排名", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmScoreRankWorker pdmScoreRankWorker)
    {
        List<PdmScoreRankWorker> list = pdmScoreRankWorkerService.selectScoreRankWorkerList(pdmScoreRankWorker);
        if ("2".equals(pdmScoreRankWorker.getTeamType()) && StringUtils.isNotEmpty(pdmScoreRankWorker.getReportYear())) {
            //外部-年
            List<PdmScoreRankWorkerYearOut> newList = BeanListUtils.copyListProperties(list,PdmScoreRankWorkerYearOut::new);
            ExcelUtil<PdmScoreRankWorkerYearOut> util = new ExcelUtil<>(PdmScoreRankWorkerYearOut.class);
            util.exportExcel(response, newList, "作业人员积分排名数据");
        }else if ("2".equals(pdmScoreRankWorker.getTeamType()) && StringUtils.isEmpty(pdmScoreRankWorker.getReportYear())) {
            //外部-月
            List<PdmScoreRankWorkerOut> newList = BeanListUtils.copyListProperties(list,PdmScoreRankWorkerOut::new);
            ExcelUtil<PdmScoreRankWorkerOut> util = new ExcelUtil<>(PdmScoreRankWorkerOut.class);
            util.exportExcel(response, newList, "作业人员积分排名数据");
        }else if("1".equals(pdmScoreRankWorker.getTeamType()) && StringUtils.isNotEmpty(pdmScoreRankWorker.getReportYear())){
            //内部-年
            List<PdmScoreRankWorkerYear> newList = BeanListUtils.copyListProperties(list,PdmScoreRankWorkerYear::new);
            ExcelUtil<PdmScoreRankWorkerYear> util = new ExcelUtil<>(PdmScoreRankWorkerYear.class);
            util.exportExcel(response, newList, "作业人员积分排名数据");
        } else{
            //内部-月
            ExcelUtil<PdmScoreRankWorker> util = new ExcelUtil<>(PdmScoreRankWorker.class);
            util.exportExcel(response, list, "作业人员积分排名数据");
        }
    }

    /**
     * 获取作业人员积分排名详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmScoreRankWorkerService.selectPdmScoreRankWorkerById(id));
    }

    /**
     * 新增作业人员积分排名
     */
    @Log(title = "作业人员积分排名", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmScoreRankWorker pdmScoreRankWorker)
    {
        return toAjax(pdmScoreRankWorkerService.insertPdmScoreRankWorker(pdmScoreRankWorker));
    }

    /**
     * 修改作业人员积分排名
     */
    @Log(title = "作业人员积分排名", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmScoreRankWorker pdmScoreRankWorker)
    {
        return toAjax(pdmScoreRankWorkerService.updatePdmScoreRankWorker(pdmScoreRankWorker));
    }

    /**
     * 删除作业人员积分排名
     */
    @Log(title = "作业人员积分排名", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmScoreRankWorkerService.deletePdmScoreRankWorkerByIds(ids));
    }
}
