package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmVehicleAlarm;
import com.ruoyi.powerdistribution.service.IPdmVehicleAlarmService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 施工车辆告警Controller
 * 
 * @author ruoyi
 * @date 2025-01-21
 */
@RestController
@RequestMapping("/powerdistribution/pdmVehicleAlarm")
public class PdmVehicleAlarmController extends BaseController
{
    @Autowired
    private IPdmVehicleAlarmService pdmVehicleAlarmService;

    /**
     * 查询施工车辆告警列表
     */
    @GetMapping("/list")
    public TableDataInfo list(PdmVehicleAlarm pdmVehicleAlarm)
    {
        startPage();
        List<PdmVehicleAlarm> list = pdmVehicleAlarmService.selectPdmVehicleAlarmList(pdmVehicleAlarm);
        return getDataTable(list);
    }

    /**
     * 导出施工车辆告警列表
     */
    @Log(title = "施工车辆告警", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmVehicleAlarm pdmVehicleAlarm)
    {
        List<PdmVehicleAlarm> list = pdmVehicleAlarmService.selectPdmVehicleAlarmList(pdmVehicleAlarm);
        ExcelUtil<PdmVehicleAlarm> util = new ExcelUtil<PdmVehicleAlarm>(PdmVehicleAlarm.class);
        util.exportExcel(response, list, "施工车辆告警数据");
    }

    /**
     * 获取施工车辆告警详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmVehicleAlarmService.selectPdmVehicleAlarmById(id));
    }

    /**
     * 新增施工车辆告警
     */
    @Log(title = "施工车辆告警", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmVehicleAlarm pdmVehicleAlarm)
    {
        return toAjax(pdmVehicleAlarmService.insertPdmVehicleAlarm(pdmVehicleAlarm));
    }

    /**
     * 修改施工车辆告警
     */
    @Log(title = "施工车辆告警", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmVehicleAlarm pdmVehicleAlarm)
    {
        return toAjax(pdmVehicleAlarmService.updatePdmVehicleAlarm(pdmVehicleAlarm));
    }

    /**
     * 删除施工车辆告警
     */
    @Log(title = "施工车辆告警", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmVehicleAlarmService.deletePdmVehicleAlarmByIds(ids));
    }
}
