package com.ruoyi.powerdistribution.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.powerdistribution.domain.PdmVehicleAlarmHist;
import com.ruoyi.powerdistribution.service.IPdmVehicleAlarmHistService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 施工车辆告警历史Controller
 * 
 * @author ruoyi
 * @date 2025-01-23
 */
@RestController
@RequestMapping("/powerdistribution/vehicleAlarmHist")
public class PdmVehicleAlarmHistController extends BaseController
{
    @Autowired
    private IPdmVehicleAlarmHistService pdmVehicleAlarmHistService;

    /**
     * 查询施工车辆告警历史列表
     */
    @GetMapping("/list")
    public TableDataInfo list(PdmVehicleAlarmHist pdmVehicleAlarmHist)
    {
        startPage();
        List<PdmVehicleAlarmHist> list = pdmVehicleAlarmHistService.selectPdmVehicleAlarmHistList(pdmVehicleAlarmHist);
        return getDataTable(list);
    }

    /**
     * 导出施工车辆告警历史列表
     */
    @Log(title = "施工车辆告警历史", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PdmVehicleAlarmHist pdmVehicleAlarmHist)
    {
        List<PdmVehicleAlarmHist> list = pdmVehicleAlarmHistService.selectPdmVehicleAlarmHistList(pdmVehicleAlarmHist);
        ExcelUtil<PdmVehicleAlarmHist> util = new ExcelUtil<PdmVehicleAlarmHist>(PdmVehicleAlarmHist.class);
        util.exportExcel(response, list, "施工车辆告警历史数据");
    }

    /**
     * 获取施工车辆告警历史详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(pdmVehicleAlarmHistService.selectPdmVehicleAlarmHistById(id));
    }

    /**
     * 新增施工车辆告警历史
     */
    @Log(title = "施工车辆告警历史", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PdmVehicleAlarmHist pdmVehicleAlarmHist)
    {
        return toAjax(pdmVehicleAlarmHistService.insertPdmVehicleAlarmHist(pdmVehicleAlarmHist));
    }

    /**
     * 修改施工车辆告警历史
     */
    @Log(title = "施工车辆告警历史", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PdmVehicleAlarmHist pdmVehicleAlarmHist)
    {
        return toAjax(pdmVehicleAlarmHistService.updatePdmVehicleAlarmHist(pdmVehicleAlarmHist));
    }

    /**
     * 删除施工车辆告警历史
     */
    @Log(title = "施工车辆告警历史", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(pdmVehicleAlarmHistService.deletePdmVehicleAlarmHistByIds(ids));
    }
}
