package com.ruoyi.powerdistribution.controller;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.alibaba.excel.write.metadata.fill.FillConfig;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.powerdistribution.domain.vo.StopTargetAndRecords;
import com.ruoyi.powerdistribution.service.IPdmStopTargeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.List;

/**
 * 停电完成情况Controller
 *
 * @author ruoyi
 * @date 2024-12-09
 */
@RestController
@Api(value = "StopTargetAndActualController", tags = "停电完成情况")
@RequestMapping("/power/stopActual")
public class StopTargetAndActualController extends BaseController {

    @Autowired
    private IPdmStopTargeService pdmStopTargeService;

    /**
     * 查询停电完成情况
     */
    @ApiOperation(value = "查询停电完成情况")
    @GetMapping("/list")
    public TableDataInfo list(String reportYear)
    {
        List<StopTargetAndRecords> list = pdmStopTargeService.selectTargetAndActual(reportYear);
        return getDataTable(list);
    }


    /**
     * 导出停电完成情况
     * @param response
     * @param reportYear
     * @throws IOException
     */
    @PostMapping("/export")
    @ApiOperation(value = "导出停电完成情况")
    public void export(HttpServletResponse response, String reportYear) throws IOException {

        List<StopTargetAndRecords> list = pdmStopTargeService.selectTargetAndActual(reportYear);

        response.setContentType("application/vnd.ms-excel");
        response.setCharacterEncoding("utf-8");
        String fileName = java.util.UUID.randomUUID() + ".xlsx";
        response.setHeader("Content-disposition", "attachment;filename=" + fileName);
        String templateFileName = "excelTemplate/stopActual.xlsx";
        InputStream fis = Thread.currentThread().getContextClassLoader().getResourceAsStream(templateFileName);
        OutputStream ops = response.getOutputStream();

        ExcelWriter excelWriter = EasyExcel.write(ops).withTemplate(fis).build();
        WriteSheet writeSheet = EasyExcel.writerSheet("总目标").build();
        FillConfig fillConfig = FillConfig.builder().forceNewRow(Boolean.TRUE).build();
        excelWriter.fill(list, fillConfig, writeSheet);
        WriteSheet writeSheet2 = EasyExcel.writerSheet("计划停电目标").build();
        excelWriter.fill(list, fillConfig, writeSheet2);
        WriteSheet writeSheet3 = EasyExcel.writerSheet("故障停电目标").build();
        excelWriter.fill(list, fillConfig, writeSheet3);
        excelWriter.finish();

    }


}
