package com.ruoyi.powerdistribution.service.impl;

import java.math.BigDecimal;
import java.util.List;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageInfo;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.powerdistribution.domain.PdmScoreRankManager;
import com.ruoyi.powerdistribution.mapper.PdmScoreRankManagerMapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.powerdistribution.mapper.PdmScoreRankTeamMapper;
import com.ruoyi.powerdistribution.domain.PdmScoreRankTeam;
import com.ruoyi.powerdistribution.service.IPdmScoreRankTeamService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 队伍积分排名Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-05
 */
@Service
public class PdmScoreRankTeamServiceImpl extends ServiceImpl<PdmScoreRankTeamMapper, PdmScoreRankTeam> implements IPdmScoreRankTeamService
{
    @Autowired
    private PdmScoreRankTeamMapper pdmScoreRankTeamMapper;

    /**
     * 查询队伍积分排名
     *
     * @param id 队伍积分排名主键
     * @return 队伍积分排名
     */
    @Override
    public PdmScoreRankTeam selectPdmScoreRankTeamById(Long id)
    {
        return pdmScoreRankTeamMapper.selectPdmScoreRankTeamById(id);
    }

    /**
     * 查询队伍积分排名列表
     *
     * @param pdmScoreRankTeam 队伍积分排名
     * @return 队伍积分排名
     */
    @Override
    public List<PdmScoreRankTeam> selectPdmScoreRankTeamList(PdmScoreRankTeam pdmScoreRankTeam)
    {
        return pdmScoreRankTeamMapper.selectPdmScoreRankTeamList(pdmScoreRankTeam);
    }

    /**
     * 新增队伍积分排名
     *
     * @param pdmScoreRankTeam 队伍积分排名
     * @return 结果
     */
    @Override
    public int insertPdmScoreRankTeam(PdmScoreRankTeam pdmScoreRankTeam)
    {
        pdmScoreRankTeam.setCreateTime(DateUtils.getNowDate());
        return pdmScoreRankTeamMapper.insertPdmScoreRankTeam(pdmScoreRankTeam);
    }

    /**
     * 修改队伍积分排名
     *
     * @param pdmScoreRankTeam 队伍积分排名
     * @return 结果
     */
    @Override
    public int updatePdmScoreRankTeam(PdmScoreRankTeam pdmScoreRankTeam)
    {
        pdmScoreRankTeam.setUpdateTime(DateUtils.getNowDate());
        return pdmScoreRankTeamMapper.updatePdmScoreRankTeam(pdmScoreRankTeam);
    }

    /**
     * 批量删除队伍积分排名
     *
     * @param ids 需要删除的队伍积分排名主键
     * @return 结果
     */
    @Override
    public int deletePdmScoreRankTeamByIds(Long[] ids)
    {
        return pdmScoreRankTeamMapper.deletePdmScoreRankTeamByIds(ids);
    }

    /**
     * 删除队伍积分排名信息
     *
     * @param id 队伍积分排名主键
     * @return 结果
     */
    @Override
    public int deletePdmScoreRankTeamById(Long id)
    {
        return pdmScoreRankTeamMapper.deletePdmScoreRankTeamById(id);
    }

    @Transactional
    @Override
    public int saveTeam(String startDate,String endDate) {
        if(StringUtils.isEmpty(startDate) || StringUtils.isEmpty(endDate)){
            startDate = DateUtils.getFirstDateLastMonthStr(DateUtils.YYYYMMDD);
            endDate = DateUtils.getLastDateLastMonthStr(DateUtils.YYYYMMDD);
        }
        String reportDate = startDate.substring(0,6);
        this.remove(new LambdaUpdateWrapper<PdmScoreRankTeam>().eq(PdmScoreRankTeam::getReportDate,reportDate));
        PdmScoreRankTeam team = new PdmScoreRankTeam();
        team.setStartDate(startDate);
        team.setEndDate(endDate);
        return pdmScoreRankTeamMapper.saveTeam(team);
    }

    @Override
    public List<PdmScoreRankTeam> getTeamRankYearList(PdmScoreRankTeam pdmScoreRankTeam) {
        return pdmScoreRankTeamMapper.getTeamRankYearList(pdmScoreRankTeam);
    }

    @Override
    public List<PdmScoreRankTeam> selectScoreRankTeamList(PdmScoreRankTeam pdmScoreRankTeam) {
        List<PdmScoreRankTeam> list;
        if(StringUtils.isNotEmpty(pdmScoreRankTeam.getReportYear())){
            list = this.getTeamRankYearList(pdmScoreRankTeam);
        }else{
            list = this.selectPdmScoreRankTeamList(pdmScoreRankTeam);
        }
        PageInfo pageInfo =  new PageInfo(list);
        int pageNum = pageInfo.getPageNum();
        int i = 1;
        int lastRankNum = 0;
        BigDecimal lastScore = new BigDecimal(0);
        for(PdmScoreRankTeam manager:list){
            int rankNum;
            if(manager.getScore().compareTo(lastScore)==0){
                rankNum = lastRankNum;
            }else{
                rankNum = pageNum!=1?(pageNum-1)*pageInfo.getPageSize()+i:i;
            }
            manager.setRankNum(rankNum);
            lastRankNum = rankNum;
            lastScore = manager.getScore();
            i++;
        }
        return list;
    }

}
