package com.ruoyi.powerdistribution.service.impl;

import java.math.BigDecimal;
import java.util.List;

import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageInfo;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.powerdistribution.domain.PdmScoreRankTeam;
import com.ruoyi.powerdistribution.mapper.PdmScoreRankTeamMapper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.powerdistribution.mapper.PdmScoreRankWorkerMapper;
import com.ruoyi.powerdistribution.domain.PdmScoreRankWorker;
import com.ruoyi.powerdistribution.service.IPdmScoreRankWorkerService;

/**
 * 作业人员积分排名Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-05
 */
@Service
public class PdmScoreRankWorkerServiceImpl extends ServiceImpl<PdmScoreRankWorkerMapper, PdmScoreRankWorker> implements IPdmScoreRankWorkerService
{
    @Autowired
    private PdmScoreRankWorkerMapper pdmScoreRankWorkerMapper;

    /**
     * 查询作业人员积分排名
     *
     * @param id 作业人员积分排名主键
     * @return 作业人员积分排名
     */
    @Override
    public PdmScoreRankWorker selectPdmScoreRankWorkerById(Long id)
    {
        return pdmScoreRankWorkerMapper.selectPdmScoreRankWorkerById(id);
    }

    /**
     * 查询作业人员积分排名列表
     *
     * @param pdmScoreRankWorker 作业人员积分排名
     * @return 作业人员积分排名
     */
    @Override
    public List<PdmScoreRankWorker> selectPdmScoreRankWorkerList(PdmScoreRankWorker pdmScoreRankWorker)
    {
        return pdmScoreRankWorkerMapper.selectPdmScoreRankWorkerList(pdmScoreRankWorker);
    }

    /**
     * 新增作业人员积分排名
     *
     * @param pdmScoreRankWorker 作业人员积分排名
     * @return 结果
     */
    @Override
    public int insertPdmScoreRankWorker(PdmScoreRankWorker pdmScoreRankWorker)
    {
        pdmScoreRankWorker.setCreateTime(DateUtils.getNowDate());
        return pdmScoreRankWorkerMapper.insertPdmScoreRankWorker(pdmScoreRankWorker);
    }

    /**
     * 修改作业人员积分排名
     *
     * @param pdmScoreRankWorker 作业人员积分排名
     * @return 结果
     */
    @Override
    public int updatePdmScoreRankWorker(PdmScoreRankWorker pdmScoreRankWorker)
    {
        pdmScoreRankWorker.setUpdateTime(DateUtils.getNowDate());
        return pdmScoreRankWorkerMapper.updatePdmScoreRankWorker(pdmScoreRankWorker);
    }

    /**
     * 批量删除作业人员积分排名
     *
     * @param ids 需要删除的作业人员积分排名主键
     * @return 结果
     */
    @Override
    public int deletePdmScoreRankWorkerByIds(Long[] ids)
    {
        return pdmScoreRankWorkerMapper.deletePdmScoreRankWorkerByIds(ids);
    }

    /**
     * 删除作业人员积分排名信息
     *
     * @param id 作业人员积分排名主键
     * @return 结果
     */
    @Override
    public int deletePdmScoreRankWorkerById(Long id)
    {
        return pdmScoreRankWorkerMapper.deletePdmScoreRankWorkerById(id);
    }

    @Override
    public List<PdmScoreRankWorker> getWorkerRankYearList(PdmScoreRankWorker pdmScoreRankWorker) {
        return pdmScoreRankWorkerMapper.getWorkerRankYearList(pdmScoreRankWorker);
    }

    @Override
    public int saveWorker(String startDate, String endDate) {
        if(StringUtils.isEmpty(startDate) || StringUtils.isEmpty(endDate)){
            startDate = DateUtils.getFirstDateLastMonthStr(DateUtils.YYYYMMDD);
            endDate = DateUtils.getLastDateLastMonthStr(DateUtils.YYYYMMDD);
        }
        String reportDate = startDate.substring(0,6);
        this.remove(new LambdaUpdateWrapper<PdmScoreRankWorker>().eq(PdmScoreRankWorker::getReportDate,reportDate));
        PdmScoreRankWorker worker = new PdmScoreRankWorker();
        worker.setStartDate(startDate);
        worker.setEndDate(endDate);
        return pdmScoreRankWorkerMapper.saveWorker(worker);
    }

    @Override
    public List<PdmScoreRankWorker> selectScoreRankWorkerList(PdmScoreRankWorker pdmScoreRankWorker) {
        List<PdmScoreRankWorker> list;
        if(StringUtils.isNotEmpty(pdmScoreRankWorker.getReportYear())){
            list = this.getWorkerRankYearList(pdmScoreRankWorker);
        }else{
            list = this.selectPdmScoreRankWorkerList(pdmScoreRankWorker);
        }
        PageInfo pageInfo =  new PageInfo(list);
        int pageNum = pageInfo.getPageNum();
        int i = 1;
        int lastRankNum = 0;
        BigDecimal lastScore = new BigDecimal(0);
        for(PdmScoreRankWorker manager:list){
            int rankNum;
            if(manager.getScore().compareTo(lastScore)==0){
                rankNum = lastRankNum;
            }else{
                rankNum = pageNum!=1?(pageNum-1)*pageInfo.getPageSize()+i:i;
            }
            manager.setRankNum(rankNum);
            lastRankNum = rankNum;
            lastScore = manager.getScore();
            i++;
        }
        return list;
    }
}
